@@ -1,6 +1,6 @@
 /*
   Copyright (c) 2007 Till Adam <adam@kde.org>
-  Copyright (C) 2012-2015 Laurent Montel <montel@kde.org>
+  Copyright (C) 2012-2018 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -87,7 +87,7 @@ public:
      * Imports filters. Ask the user where to import them from
      * and which filters to import.
      */
-    QList<MailFilter *> importFilters(
+    Q_REQUIRED_RESULT QList<MailFilter *> importFilters(
         bool &canceled, FilterImporterExporter::FilterType type = FilterImporterExporter::KMailFilter, const QString &filename = QString());
 
     /**
