@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,8 +20,7 @@
 
 #include "searchpattern.h"
 #include <AkonadiCore/Item>
-namespace MailCommon
-{
+namespace MailCommon {
 /**
  * @short This class represents a search pattern rule operating on numerical values.
  *
@@ -38,24 +37,22 @@ public:
      * @param function The function to use for searching.
      * @param contents The contents to search for.
      */
-    explicit SearchRuleNumerical(const QByteArray &field = QByteArray(),
-                                 Function function = FuncContains,
-                                 const QString &contents = QString());
+    explicit SearchRuleNumerical(const QByteArray &field = QByteArray(), Function function = FuncContains, const QString &contents = QString());
 
     /**
      * @copydoc SearchRule::isEmpty()
      */
-    bool isEmpty() const  Q_DECL_OVERRIDE;
+    bool isEmpty() const override;
 
     /**
      * @copydoc SearchRule::matches()
      */
-    bool matches(const Akonadi::Item &item) const Q_DECL_OVERRIDE;
+    bool matches(const Akonadi::Item &item) const override;
 
     /**
      * @copydoc SearchRule::requiredPart()
      */
-    RequiredPart requiredPart() const Q_DECL_OVERRIDE;
+    RequiredPart requiredPart() const override;
 
     // Optimized matching not implemented, will use the unoptimized matching
     // from SearchRule
@@ -65,15 +62,13 @@ public:
      * A helper method for the main matches() method.
      * Does the actual comparing.
      */
-    bool matchesInternal(long numericalValue, long numericalContents,
-                         const QString &contents) const;
+    bool matchesInternal(long numericalValue, long numericalContents, const QString &contents) const;
 
     /**
      * @copydoc SearchRule::addQueryTerms()
      */
-    void addQueryTerms(Akonadi::SearchTerm &groupTerm, bool &emptyIsNotAnError) const Q_DECL_OVERRIDE;
-    QString informationAboutNotValidRules() const Q_DECL_OVERRIDE;
-
+    void addQueryTerms(Akonadi::SearchTerm &groupTerm, bool &emptyIsNotAnError) const override;
+    QString informationAboutNotValidRules() const override;
 };
 }
 #endif // SEARCHRULENUMERICAL_H
